#########################################################
####     Luhmann - R fr Einsteiger - 3. Auflage    #####
####              Kapitel 13 - t-Tests              #####
#########################################################


# Beispieldaten laden 
setwd("D:/Ordner 1/Ordner 2")
load("erstis.RData")

attach(erstis)

library(psych)


#### Abschnitt 13.1 ####

# Stichprobengre und deskriptive Statistiken
describe(neuro)
desc <- describe(neuro)


# nortest-Paket installieren und laden
install.packages("nortest")
library(nortest)

# Lilliefors-Test
lillie.test(neuro)

# t-Test fr eine Stichprobe: ungerichtet
t.test(neuro, mu=3.3)

# t-Test fr eine Stichprobe: gerichtet
t.test(neuro,mu=3.3, alternative="greater")

# Konfidenzintervall anpassen
t.test(neuro, mu=3.3, conf.level=0.99)

# Effektgre: MBESS-Paket installieren und laden
install.packages("MBESS")
library(MBESS)

# Effektgre berechnen
ci.sm(Mean = desc$mean -3.3, SD = desc$sd, N = desc$n)



#### Abschnitt 13.2 ####

# Stichprobengre und deskriptive Statistiken fr Neurotizismus
desc.2 <- describeBy(neuro, geschl, mat = TRUE)
desc.2

# Gesamtstichprobe fr Neurotizismus
sum(desc.2$n)

# Gesamtstichprobe fr Gewissenhaftigkeit
describeBy(gewiss, geschl, mat = TRUE)$n

# Levene-Test
library(car)
leveneTest(neuro, geschl)
leveneTest(gewiss, geschl)

# t-Test bei Varianzgleichheit
t.test(neuro ~ geschl, var.equal=TRUE)

# Welch-Test bei Varianzungleichheit
t.test(gewiss ~ geschl)

# Reihenfolge der Gruppen nachschauen
levels(geschl)

# Effektgre
ci.smd(ncp = t.test(neuro ~ geschl)$statistic, 
	n.1 = desc.2$n[1], n.2 = desc.2$n[2])



#### Abschnitt 13.3 ####

# Stichprobengre und Korrelation
auswahl <- na.omit(data.frame(zuf.inh.1, zuf.inh.2))
describe(auswahl)
cor(auswahl)

# t-Test fr abhngige Stichproben
t.test(zuf.inh.1, zuf.inh.2, paired=TRUE, alternative="greater")

### Effektgre

# Standardabweichung der Differenzvariablen
sd.diff <- sd(zuf.inh.1 - zuf.inh.2, na.rm = TRUE)

# Ausgabe des t-Tests als Objekt speichern
t.ausgabe <- t.test(zuf.inh.1, zuf.inh.2, paired=TRUE, alternative="greater")

# Mittelwertsdifferenz
t.ausgabe$estimate

# Effektgre
ci.sm(Mean=t.ausgabe$estimate, SD=sd.diff, N=49)

