############################################################
####      Luhmann - R fr Einsteiger - 4. Auflage      #####
#### Kapitel 15 - Varianzanalyse mit Messwiederholung  #####
############################################################


# Beispieldaten laden 
setwd("D:/Ordner 1/Ordner 2")
load("prfung.RData")


#### Abschnitt 15.1 ####

# Fehlende Werte lschen
prfung.reduz <- na.omit(prfung)

# Long-Format
prfung.long <- reshape(prfung.reduz, idvar="nr", 
	varying=c("gs.1", "gs.2", "gs.3", "ru.1", "ru.2", "ru.3"), 
	timevar="zeitpunkt", direction = "long")

View(prfung.long)


#### Abschnitt 15.2 ####

# Deskriptive Statistiken und Diagramm mit Fehlerbalken

library(psych)

attach(prfung.reduz)

describe(data.frame(gs.1, gs.2, gs.3))
error.bars(data.frame(gs.1, gs.2, gs.3), 
	within = T, type = "b", pch = 16, eyes = FALSE)

detach(prfung.reduz)

# ez-Paket installieren und laden
install.packages("ez")
library(ez)

# Variablen nr und zeitpunkt als Faktoren speichern

prfung.long$nr <- factor(prfung.long$nr)
prfung.long$zeitpunkt <- factor(prfung.long$zeitpunkt)


# Durchfhrung der einfaktoriellen messwiederholten Varianzanalyse
anova.rm <- ezANOVA(prfung.long, dv = gs, wid = nr, within = zeitpunkt)
anova.rm

# Deskriptive Statistiken mit Fisher's Least Significant Difference
ezStats(prfung.long, dv = gs, wid = nr, within = zeitpunkt)

# Fishers Least Significant Difference: Schritte
t1.t2 <- 3.460674 - 3.901685 
t1.t3 <- 3.460674 - 4.466292 
t2.t3 <- 3.901685 - 4.466292
abs(t1.t2)
abs(t1.t3)
abs(t2.t3)

flsd <- 0.2066795
abs(t1.t2) > flsd
abs(t1.t3) > flsd
abs(t2.t3) > flsd

# Post-hoc-Vergleiche mit Bonferroni-Korrektur
attach(prfung.long)
pairwise.t.test(gs, zeitpunkt, p.adj = "bonferroni", paired=TRUE)
detach(prfung.long)



#### Abschnitt 15.3 ####

# Deskriptive Statistiken

attach(prfung.reduz)

describeBy(data.frame(gs.1, gs.2, gs.3), sex)

error.bars.by(data.frame(gs.1, gs.2, gs.3), sex,
	within = T, lty = c(1,2), eyes = FALSE)

legend("topleft", levels(sex), lty = c(1,2))

detach(prfung.reduz)

# Durchfhrung der zweifaktoriellen gemischten Varianzanalyse
# mit Typ-III-Quadratsummen
anova.mixed <- ezANOVA(prfung.long, dv=gs, 
	wid=nr, within=zeitpunkt, between=sex, type = 3)

anova.mixed





