############################################################
####      Luhmann - R fr Einsteiger - 4. Auflage      #####
####   Kapitel 16 - Grundlagen Regressionsanalyse      #####
############################################################



# Beispieldaten laden 
setwd("D:/Ordner 1/Ordner 2")
load("erstis.RData")

attach(erstis)


#### Abschnitt 16.1 ####

# Unstandardisierte Regressionskoeffizienten
lm(lz.1 ~ zuf.inh.1)

# Standardisierte Regressionskoeffizienten
lm(scale(lz.1) ~ scale(zuf.inh.1))

# Signifikanztests
einf.reg <- lm(lz.1 ~ zuf.inh.1)
summary(einf.reg)

# Konfidenzintervalle 
confint(einf.reg)
confint(einf.reg, level=0.99)

# Vorhergesagte Werte fr Personen
fitted(einf.reg)

# Residuen fr Personen
resid(einf.reg)

# Vorhergesagter Wert fr einen bestimmten x-Wert
predict(einf.reg, list(zuf.inh.1=4))


#### Abschnitt 16.2 ####

# Multiple Regression
mult.reg <- lm(lz.1 ~ zuf.inh.1 + zuf.bed.1)
summary(mult.reg)

# Koeffiziententabelle exportieren
write.csv2(summary(mult.reg)$coefficients, file = "Regression.csv")

# Multiple Korrelation: Berechnung ber R2
summary(mult.reg)$r.squared
sqrt(summary(mult.reg)$r.squared)

# Hierarchische Regression: Stichprobe auswhlen
data.fuer.regression <- na.omit(data.frame(lz.1, zuf.inh.1, zuf.bed.1, neuro, gewiss))

# Hierarchische Regression: Neue Stichprobengre
nrow(data.fuer.regression)

# Hierarchische Regression: Reduziertes Modell
red.model <- lm(lz.1 ~ zuf.inh.1 + zuf.bed.1, data = data.fuer.regression)
summary(red.model)$r.squared

# Hierarchische Regression: Vollstndiges Modell
voll.model <- lm(lz.1 ~ zuf.inh.1 +  zuf.bed.1 + neuro + gewiss, data = data.fuer.regression)
summary(voll.model)$r.squared

# Hierarchische Regression: Zuwachs in R2
summary(voll.model)$r.squared - summary(red.model)$r.squared

# Hierarchische Regression: Modellvergleich mit ANOVA
anova(red.model,voll.model)

# Hierarchische Regression: Modellvergleich mit AIC
AIC(red.model, voll.model)

# Schrittweise Regression
auswahl <- na.omit(data.frame(lz.1, neuro, extra, gewiss, vertraeg, intell))

step.input <- lm(lz.1 ~ 1, data = auswahl)
step.output <- step(step.input,   scope = ~ neuro + 
	extra + gewiss + vertraeg + intell)

summary(step.output)


 
#### Abschnitt 16.4 ####

# Residuenplots
par(mfrow=c(2,2))
plot(mult.reg)

par(mfrow=c(1,1))
plot(mult.reg)

# Funktionen zur Identifizierung von Ausreiern und 
# einflussreichen Werten

resid(mult.reg)
rstandard(mult.reg)
rstudent(mult.reg)
dfbeta(mult.reg)
dfbetas(mult.reg)
dffits(mult.reg)
cooks.distance(mult.reg)


# Variance Inflation Factor
library(car)
vif(mult.reg)

# Toleranz
1/vif(mult.reg)


#### Abschnitt 16.5 ####

# Neuen Data Frame erstellen 
var.auswahl <- na.omit(data.frame(lz.1, zuf.inh.1, zuf.bed.1))

# Bivariate Korrelationen
round(cor(var.auswahl), 2)

# Partialkorrelationen
partial.r(var.auswahl, c(2,3), 1)

# Semipartialkorrelation: Schritte
zsi.resid <- resid(lm(zuf.inh.1 ~ zuf.bed.1, data = var.auswahl))
cor(var.auswahl$lz.1, zsi.resid)

