############################################################
####      Luhmann - R fr Einsteiger - 3. Auflage      #####
####    Kapitel 17 - Spezielle Regressionsmodelle      #####
############################################################


# Beispieldaten laden 
setwd("D:/Ordner 1/Ordner 2")
load("erstis.RData")

attach(erstis)


#### Abschnitt 17.1 ####

# Kodierung anschauen
contrasts(gruppe)

# Neue Variable mit anderer Referenzgruppe anlegen
erstis$gruppe.2 <- relevel(gruppe, "Kurs 2")
contrasts(erstis$gruppe.2)

# Regression mit kategorialen Prdiktoren
reg.kat <- lm(alter ~ gruppe)
summary(reg.kat)

# Kontraste erstellen lassen
contr.sum(4) 
contr.helmert(4) 
contr.poly(4) 


#### Abschnitt 17.2 ####

# Prdiktoren zentrieren
erstis$wm_cen <- as.numeric(scale(wm.1, scale = FALSE))
erstis$gs_cen <- as.numeric(scale(gs.1, scale = FALSE))

detach(erstis)
attach(erstis)


# Berechnung der Regressionskoeffizienten 
mod.reg <- lm(lz.1 ~ wm_cen * gs_cen)
summary(mod.reg)

# rockchalk-Paket installieren und laden
install.packages("rockchalk")
library(rockchalk)

# Bedingte Regressionsgleichungen darstellen
slopes = plotSlopes(mod.reg, plotx = "wm_cen", modx = "gs_cen")

# Angepasste Variante
slopes.a = plotSlopes(mod.reg, plotx = "wm_cen", modx = "gs_cen", 
	plotPoints = FALSE, col = c(1,1,1))

# Werte fr das Interaktionsdiagramm
slopes

# Test der bedingten Steigungskoeffizienten
testSlopes(slopes)



#### Abschnitt 17.3 ####

# Alter zentrieren
erstis$alter.cen <- scale(alter, scale = FALSE)

detach(erstis)
attach(erstis)

# Nicht-lineare Regression
quadr <- lm(ru.1 ~ alter.cen + I(alter.cen^2))
summary(quadr)

# Diagramm
plot(alter.cen, ru.1, xlab = "Alter zentriert", 
	ylab = "Ruhige vs. unruhige Stimmung")

# Regressionskurve fr den quadratischen Zusammenhang
curve(3.1641734 -0.036290*x + 0.0021316*(x^2), add=TRUE)

# Regressionsgerade fr den linearen Zusammenhang
abline(lm(ru.1~alter.cen))


#### Abschnitt 17.4 ####

# Prdiktor zentrieren
neuro.cen <- as.numeric(scale(neuro, scale=FALSE))

# Kovarianzanalyse
cov.analyse.1 <- lm(lz.1 ~ neuro.cen * geschl)
summary(cov.analyse.1)

# Bedingte Regressionsgleichungen: Interaktionsdiagramm
slopes <- plotSlopes(cov.analyse.1, plotx = "neuro.cen", modx = "geschl")

# Bedingte Regressionsgleichungen: Test der simple slopes
testSlopes(slopes)


#### Abschnitt 17.5 ####

# Regressionskoeffizienten
log.reg <- glm(berlin ~ lz.1, family=binomial)
summary(log.reg)

# Einzelne Koeffizienten
coef(log.reg)

# Odds Ratios
exp(coef(log.reg)) 

# Konfidenzintervalle fr Odds Ratios
exp(confint(log.reg)) 

# Modellvergleiche: Auswahl der Stichprobe
data.log.reg <- na.omit(data.frame(berlin, lz.1, neuro))

# Modellvergleiche: Modell 1
log.reg.1 <- glm(berlin ~ lz.1, family=binomial, data = data.log.reg)
summary(log.reg.1)

# Modellvergleiche: Modell 2
log.reg.2 <- glm(berlin ~ lz.1 + neuro, family=binomial, data = data.log.reg)
summary(log.reg.2)

# Modellvergleich mit chi2-Wert
anova(log.reg.1, log.reg.2, test="Chi")


