##################################################
#### Luhmann - R fr Einsteiger - 3. Auflage #####
####      Kapitel 7 - Variablen bearbeiten   #####
##################################################

# Beispieldaten laden 
setwd("D:/Ordner 1/Ordner 2")
load("bigfive.RData")

library(psych)
?score.items

#### Abschnitt 7.1 ####

# Daten mit attach-Funktion aktivieren
attach(bigfive)

# Mittelwert fr Item bf01 berechnen
mean(bf01)

# Daten mit detach-Funktion deaktivieren
detach(bigfive)

# Item bf01 wird jetzt nicht gefunden
mean(bf01)

# Auswahl mit dem Dollarzeichen
mean(bigfive$bf01)

# Neue Variable hinzufgen
bigfive$neu <- NA

# Alle Elemente in einem Objekt anzeigen lassen
str(bigfive)

# Auswahl eines bestimmten Werts ber die Index-Funktion
bigfive$bf01[2]
bigfive[3,2]

# Auswahl einer Variablen ber die Index-Funktion
mean(bigfive[ ,2])
mean(bigfive[, "bf01"])

# Ausschluss einer bestimmten Zeile 
mean(bigfive[-3,2])

# Auswahl mehrerer Variablen mit der data.frame-Funktion
auswahl.1 <- data.frame(bigfive$bf01, bigfive$bf02)
colMeans(auswahl.1)

# Auswahl mehrerer Variablen und Definition neuer Variablennamen
auswahl.2 <- data.frame(bf1 = bigfive$bf01, bf2 = bigfive$bf02)
colMeans(auswahl.2)

# Auswahl mehrerer Variablen ber die Index-Funktion
auswahl.3 <- bigfive[ ,c(2,3)]
auswahl.3 <- bigfive[ ,c("bf01", "bf02")]
colMeans(auswahl.3)

# Auswahl mehrerer Variablen mit der subset-Funktion
auswahl.2 <- subset(bigfive, select=bf19:alter)
colMeans(auswahl.2)


#### Abschnitt 7.2 ####

# Vektor sex wird in Faktor konvertiert, die alte Variable wird berschrieben
bigfive$sex <- factor(bigfive$sex)

# Vektor sex wird in Faktor konvertiert, die alte Variable wird beibehalten
bigfive$sex.faktor <- factor(bigfive$sex)

# Vektor sex wird in Faktor konvertiert, Wertelabels werden vergeben 
bigfive$sex.faktor <- factor(bigfive$sex, 
	levels=c(1,2), 
	labels=c("weiblich", "mnnlich"))

# Objekttyp von "geschl.faktor" feststellen
class(bigfive$sex.faktor)

# Faktorstufen mit Wertelabels anfordern
levels(bigfive$sex.faktor)

# Faktor "sex.faktor" in Vektor konvertieren
bigfive$sex.vektor <- as.numeric(bigfive$sex.faktor)

# Objekttyp bestimmen
class(bigfive$sex.vektor)

# Werte ausgeben lassen
bigfive$sex.vektor




#### Abschnitt 7.3 ####

# Geburtsjahr berechnen und als Variable anlegen
bigfive$gebjahr <- 2001 - bigfive$alter 

# Mittelwert fr Neurotizismus berechnen
bigfive$neuro <- (bigfive$bf04 + bigfive$bf10 + bigfive$bf12 + bigfive$bf19)/4

# Summenwert fr Neurotizismus berechnen
bigfive$neuro <- bigfive$bf04 + bigfive$bf10 + bigfive$bf12 + bigfive$bf19

# Mittelwert mit der rowMeans-Funktion berechnen
bigfive$neuro <- rowMeans(bigfive[c("bf04","bf10","bf12","bf19")])

# Noch mal die rowMeans-Funktion, diesmal mit anderer Auswahl der Variablen
attach(bigfive)
bigfive$neuro <- rowMeans(data.frame(bf04,bf10,bf12,bf19))
detach(bigfive)

# Mittelwert mit der rowMeans-Funktion berechnen, fehlende Werte sind erlaubt
bigfive$neuro <- rowMeans(bigfive[c("bf04","bf10","bf12", "bf19")], 
	na.rm=TRUE)

# Summenwert mit der rowSums-Funktion berechnen
bigfive$neuro <- rowSums(bigfive[c("bf04","bf10","bf12","bf19")])

# Alter standardisieren
bigfive$alter.z <- scale(bigfive$alter)

# Alter zentrieren
bigfive$alter.cen <- scale(bigfive$alter, scale=FALSE)

# Variable umpolen
bigfive$bf04r <- 6 - bigfive$bf04
table(bigfive$bf04r, bigfive$bf04)

# Einzelne Werte mit der which-Funktion umkodieren
which(bigfive$bf04 == 1)
bigfive$bf04[which(bigfive$bf04 == 1)]
bigfive$bf04[which(bigfive$bf04 == 1)] <- NA
table(bigfive$bf04)

# Mehrere Werte mit der which-Funktion umkodieren
bigfive$altersgruppe[which(bigfive$alter < 30)] <- 0
bigfive$altersgruppe[which(bigfive$alter >= 30)] <- 1
table(bigfive$alter, bigfive$altersgruppe)

# Mehrere Werte mit der ifelse-Funktion umkodieren
bigfive$altersgruppe <- ifelse(bigfive$alter >= 30, 1, 0)
table(bigfive$alter, bigfive$altersgruppe)

# Komplexere Variante der ifelse-Funktion
bigfive$altersgruppe <- ifelse(bigfive$alter >= 30, 1, 
			ifelse(bigfive$alter < 20, 3, 2))
table(bigfive$alter, bigfive$altersgruppe)

# Variable mit der recode-Funktion umkodieren
library(car)
bigfive$bf03r <- recode(bigfive$bf03, '1=5; 2=4; 3=3; 4=2; 5=1;')
table(bigfive$bf03, bigfive$bf03r)



